/**
 * Copyright (c) 2019 Gregorius Techneticies
 *
 * This file is part of GregTech.
 *
 * GregTech is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GregTech is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with GregTech. If not, see <http://www.gnu.org/licenses/>.
 */

package gregapi.load;

import gregapi.data.MD;
import gregapi.data.MT;
import gregapi.data.OP;
import gregapi.oredict.OreDictManager;
import gregapi.util.ST;
import net.minecraft.init.Blocks;
import net.minecraft.init.Items;

/**
 * @author Gregorius Techneticies
 */
public class LoaderUnificationTargets implements Runnable {
	@Override public String toString() {return "Unification Target Loader";}
	
	@Override
	public void run() {
		// Because most Mods (and vanilla MC) are not OreDict Compatible and need to be set as Target manually.
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Bone                   , ST.make(MD.Fossil, "fossil", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Amber                  , ST.make(MD.Fossil, "amberOre", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Amber                  , ST.make(MD.Fossil, "amber", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.AmberDominican         , ST.make(MD.Fossil, "DominicanAmber", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreDense       , MT.Coal                   , ST.make(MD.MF2, "oreCoalRich", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Niter                  , ST.make(MD.MF2, "oreNitre", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.S                      , ST.make(MD.MF2, "oreSulfur", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Sn                     , ST.make(MD.MF2, "oreTin", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Cu                     , ST.make(MD.MF2, "oreCopper", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Ag                     , ST.make(MD.MF2, "oreSilver", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.W                      , ST.make(MD.MF2, "oreTungsten", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.OREMATS.Borax          , ST.make(MD.MF2, "oreBorax", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.OREMATS.Kaolinite      , ST.make(MD.MF2, "oreKaolinite", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.EnderPearl             , ST.make(MD.MF2, "ender_block", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Ad                     , ST.make(MD.MF2, "adamantium_block", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Mithril                , ST.make(MD.MF2, "mithril_block", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.BlackSteel             , ST.make(MD.MF2, "blacksteel_block", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.BlueSteel              , ST.make(MD.MF2, "bluesteel_block", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.RedSteel               , ST.make(MD.MF2, "redsteel_block", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Steel                  , ST.make(MD.MF2, "steel_block", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Bronze                 , ST.make(MD.MF2, "bronze_block", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Cu                     , ST.make(MD.MF2, "copper_block", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Sn                     , ST.make(MD.MF2, "tin_block", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Ag                     , ST.make(MD.MF2, "silver_block", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.PigIron                , ST.make(MD.MF2, "pigiron_block", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.S                      , ST.make(MD.MF2, "MF_Com_sulfur", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Niter                  , ST.make(MD.MF2, "MF_Com_nitre", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.OREMATS.Kaolinite      , ST.make(MD.MF2, "MF_Com_kaolinite", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dustSmall      , MT.OREMATS.Borax          , ST.make(MD.MF2, "MF_Com_flux_strong", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dustSmall      , MT.Limestone              , ST.make(MD.MF2, "MF_Com_flux", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Meteorite              , ST.make(MD.FM, "MeteoriteIngot", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.FrozenIron             , ST.make(MD.FM, "FrozenIron", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Kreknorite             , ST.make(MD.FM, "KreknoriteIngot", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Frezarite              , ST.make(MD.FM, "FrezaCrystal", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.RedMeteor              , ST.make(MD.FM, "RedMeteorGem", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.RedMeteor              , ST.make(MD.FM, "BlockRedMeteorGem", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Meteorite              , ST.make(MD.FM, "BlockMeteorDecoration", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.FrozenIron             , ST.make(MD.FM, "BlockMeteorDecoration", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Kreknorite             , ST.make(MD.FM, "BlockMeteorDecoration", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Cu                     , ST.make(MD.GC, "item.basicItem", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Sn                     , ST.make(MD.GC, "item.basicItem", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Al                     , ST.make(MD.GC, "item.basicItem", 1, 8));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Steel                  , ST.make(MD.GC, "item.basicItem", 1, 9));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Bronze                 , ST.make(MD.GC, "item.basicItem", 1,10));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Fe                     , ST.make(MD.GC, "item.basicItem", 1,11));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.MeteoricIron           , ST.make(MD.GC, "item.meteoricIronIngot", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.MeteoricIron           , ST.make(MD.GC, "item.meteoricIronIngot", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.MeteoricIron           , ST.make(MD.GC, "tile.gcBlockCore", 1, 12));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Desh                   , ST.make(MD.GC_PLANETS, "item.null", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Desh                   , ST.make(MD.GC_PLANETS, "item.null", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Desh                   , ST.make(MD.GC_PLANETS, "item.null", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Desh                   , ST.make(MD.GC_PLANETS, "tile.mars", 1, 8));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Ti                     , ST.make(MD.GC_PLANETS, "item.itemBasicAsteroids", 1, 6));
		if (MD.GC_GALAXYSPACE.mLoaded) if (ST.valid(ST.make(MD.GC_GALAXYSPACE, "dungeonglowstone", 1, 0))) {
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Co                     , ST.make(MD.GC_GALAXYSPACE, "ores", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Ni                     , ST.make(MD.GC_GALAXYSPACE, "ores", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.BlueSapphire           , ST.make(MD.GC_GALAXYSPACE, "ores", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.OREMATS.Uraninite      , ST.make(MD.GC_GALAXYSPACE, "ores", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.BlueSapphire           , ST.make(MD.GC_GALAXYSPACE, "ores", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.BlueSapphire           , ST.make(MD.GC_GALAXYSPACE, "item.BasicItems", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Dolomite               , ST.make(MD.GC_GALAXYSPACE, "item.BasicItems", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Co                     , ST.make(MD.GC_GALAXYSPACE, "item.Ingots", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Mg                     , ST.make(MD.GC_GALAXYSPACE, "item.Ingots", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Ni                     , ST.make(MD.GC_GALAXYSPACE, "item.Ingots", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Co                     , ST.make(MD.GC_GALAXYSPACE, "item.CompressedPlates", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Mg                     , ST.make(MD.GC_GALAXYSPACE, "item.CompressedPlates", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Ni                     , ST.make(MD.GC_GALAXYSPACE, "item.CompressedPlates", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Coal                   , ST.make(MD.GC_GALAXYSPACE, "item.CompressedPlates", 1, 3));
		} else {
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Adamantite             , ST.make(MD.GC_GALAXYSPACE, "item.Ingots", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Duralumin              , ST.make(MD.GC_GALAXYSPACE, "item.Ingots", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Oriharukon             , ST.make(MD.GC_GALAXYSPACE, "item.Ingots", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Adamantite             , ST.make(MD.GC_GALAXYSPACE, "item.CompressedPlates", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Co                     , ST.make(MD.GC_GALAXYSPACE, "item.CompressedPlates", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Duralumin              , ST.make(MD.GC_GALAXYSPACE, "item.CompressedPlates", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Pb                     , ST.make(MD.GC_GALAXYSPACE, "item.CompressedPlates", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Mg                     , ST.make(MD.GC_GALAXYSPACE, "item.CompressedPlates", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Mithril                , ST.make(MD.GC_GALAXYSPACE, "item.CompressedPlates", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Ni                     , ST.make(MD.GC_GALAXYSPACE, "item.CompressedPlates", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Oriharukon             , ST.make(MD.GC_GALAXYSPACE, "item.CompressedPlates", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.Pt                     , ST.make(MD.GC_GALAXYSPACE, "item.CompressedPlates", 1, 8));
		OreDictManager.INSTANCE.setTarget(OP.compressed     , MT.W                      , ST.make(MD.GC_GALAXYSPACE, "item.CompressedPlates", 1, 9));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Pb                     , ST.make(MD.GC_GALAXYSPACE, "metalsblock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Adamantite             , ST.make(MD.GC_GALAXYSPACE, "metalsblock", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Co                     , ST.make(MD.GC_GALAXYSPACE, "metalsblock", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Mg                     , ST.make(MD.GC_GALAXYSPACE, "metalsblock", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Mithril                , ST.make(MD.GC_GALAXYSPACE, "metalsblock", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Ni                     , ST.make(MD.GC_GALAXYSPACE, "metalsblock", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Oriharukon             , ST.make(MD.GC_GALAXYSPACE, "metalsblock", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Pt                     , ST.make(MD.GC_GALAXYSPACE, "metalsblock", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.W                      , ST.make(MD.GC_GALAXYSPACE, "metalsblock", 1, 8));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Duralumin              , ST.make(MD.GC_GALAXYSPACE, "metalsblock", 1, 9));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.GlowstoneCeres         , ST.make(MD.GC_GALAXYSPACE, "item.GlowstoneDusts", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.GlowstoneIo            , ST.make(MD.GC_GALAXYSPACE, "item.GlowstoneDusts", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.GlowstoneEnceladus     , ST.make(MD.GC_GALAXYSPACE, "item.GlowstoneDusts", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.GlowstoneProteus       , ST.make(MD.GC_GALAXYSPACE, "item.GlowstoneDusts", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.GlowstonePluto         , ST.make(MD.GC_GALAXYSPACE, "item.GlowstoneDusts", 1, 4));
		}
		OreDictManager.INSTANCE.setTarget(OP.gearGt         , MT.TitaniumAluminide      , ST.make(MD.GC_ADV_ROCKETRY, "advancedRocketryproductgear", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gearGt         , MT.Iritanium              , ST.make(MD.GC_ADV_ROCKETRY, "advancedRocketryproductgear", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.sheetGt        , MT.TitaniumAluminide      , ST.make(MD.GC_ADV_ROCKETRY, "advancedRocketryproductsheet", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.sheetGt        , MT.Iritanium              , ST.make(MD.GC_ADV_ROCKETRY, "advancedRocketryproductsheet", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.sheetGt        , MT.Fe                     , ST.make(MD.VULPES, "libVulpesproductsheet", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.sheetGt        , MT.Cu                     , ST.make(MD.VULPES, "libVulpesproductsheet", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.sheetGt        , MT.Steel                  , ST.make(MD.VULPES, "libVulpesproductsheet", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.sheetGt        , MT.Ti                     , ST.make(MD.VULPES, "libVulpesproductsheet", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.sheetGt        , MT.Al                     , ST.make(MD.VULPES, "libVulpesproductsheet", 1, 9));
		OreDictManager.INSTANCE.setTarget(OP.gearGt         , MT.Steel                  , ST.make(MD.VULPES, "libVulpesproductgear", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.gearGt         , MT.Ti                     , ST.make(MD.VULPES, "libVulpesproductgear", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Dilithium              , ST.make(MD.VULPES, "libVulpesproductdust", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Dilithium              , ST.make(MD.VULPES, "libVulpesproductcrystal", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.Manasteel              , ST.make(MD.TCFM, "FMResource", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.ElvenElementium        , ST.make(MD.TCFM, "FMResource", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.FierySteel             , ST.make(MD.TF, "item.fieryIngot", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Knightmetal            , ST.make(MD.TF, "item.knightMetal", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Steeleaf               , ST.make(MD.TF, "item.steeleafIngot", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.IronWood               , ST.make(MD.TF, "item.ironwoodIngot", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Knightmetal            , ST.make(MD.TF, "tile.KnightmetalBlock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.An                     , ST.make(MD.ABYSSAL, "abyblock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Cor                    , ST.make(MD.ABYSSAL, "corblock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Dr                     , ST.make(MD.ABYSSAL, "dreadiumblock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Etx                    , ST.make(MD.ABYSSAL, "ethaxiumblock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.An                     , ST.make(MD.ABYSSAL, "abyingot", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Cor                    , ST.make(MD.ABYSSAL, "cingot", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Dr                     , ST.make(MD.ABYSSAL, "dreadumingot", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Etx                    , ST.make(MD.ABYSSAL, "ethaxiumingot", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.An                     , ST.make(MD.ABYSSAL, "ingotnugget", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.Cor                    , ST.make(MD.ABYSSAL, "ingotnugget", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.Dr                     , ST.make(MD.ABYSSAL, "ingotnugget", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.Etx                    , ST.make(MD.ABYSSAL, "ingotnugget", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Cor                    , ST.make(MD.ABYSSAL, "coralium", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Redstone               , ST.make(MD.ABYSSAL, "crystal", 1, 11));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Niter                  , ST.make(MD.ABYSSAL, "nitreore", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.An                     , ST.make(MD.ABYSSAL, "abyore", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Cor                    , ST.make(MD.ABYSSAL, "coraliumore", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Jade                   , ST.make(MD.ERE, "blockJade", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Jade                   , ST.make(MD.ERE, "materials", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.gemFlawless    , MT.Redstone               , ST.make(MD.ERE, "materials", 1,12));
		OreDictManager.INSTANCE.setTarget(OP.rockGt         , MT.Gneiss                 , ST.make(MD.ERE, "materials", 1,48));
		OreDictManager.INSTANCE.setTarget(OP.rockGt         , MT.PetrifiedWood          , ST.make(MD.ERE, "materials", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.PetrifiedWood          , ST.make(MD.ERE, "petrifiedWoodPlanks", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreUmberstone  , MT.PetrifiedWood          , ST.make(MD.ERE, "orePetrifiedWood", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreUmberstone  , MT.Gneiss                 , ST.make(MD.ERE, "oreGneiss", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreUmberstone  , MT.Bone                   , ST.make(MD.ERE, "oreFossil", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreUmberstone  , MT.Fe                     , ST.make(MD.ERE, "oreIron", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreUmberstone  , MT.Au                     , ST.make(MD.ERE, "oreGold", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreUmberstone  , MT.Ag                     , ST.make(MD.ERE, "oreSilver", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreUmberstone  , MT.Cu                     , ST.make(MD.ERE, "oreCopper", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreUmberstone  , MT.Sn                     , ST.make(MD.ERE, "oreTin", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreUmberstone  , MT.Pb                     , ST.make(MD.ERE, "oreLead", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreUmberstone  , MT.Al                     , ST.make(MD.ERE, "oreAluminium", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreUmberstone  , MT.Coal                   , ST.make(MD.ERE, "oreCoal", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreUmberstone  , MT.Emerald                , ST.make(MD.ERE, "oreEmerald", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreUmberstone  , MT.Diamond                , ST.make(MD.ERE, "oreDiamond", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreUmberstone  , MT.NetherQuartz           , ST.make(MD.ERE, "oreQuartz", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreUmberstone  , MT.Lapis                  , ST.make(MD.ERE, "oreLapis", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreUmberstone  , MT.Jade                   , ST.make(MD.ERE, "oreJade", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Scabyst                , ST.make(MD.BTL, "unknownGeneric", 1, 42));
		OreDictManager.INSTANCE.setTarget(OP.orePitstone    , MT.Scabyst                , ST.make(MD.BTL, "scabystOre", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.SlimyBone              , ST.make(MD.BTL, "unknownGeneric", 1, 17));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.SlimyBone              , ST.make(MD.BTL, "slimyBoneBlock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreBetweenstone, MT.SlimyBone              , ST.make(MD.BTL, "boneOre", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Weedwood               , ST.make(MD.BTL, "unknownGeneric", 1, 23));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.CrimsonMiddle          , ST.make(MD.BTL, "groundStuff", 1, 28));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.CrimsonMiddle          , ST.make(MD.BTL, "crimsonMiddleGem", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.CrimsonMiddle          , ST.make(MD.BTL, "crimsonMiddleGemBlock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreMud         , MT.CrimsonMiddle          , ST.make(MD.BTL, "crimsonMiddleGemOre", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.GreenMiddle            , ST.make(MD.BTL, "groundStuff", 1, 32));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.GreenMiddle            , ST.make(MD.BTL, "greenMiddleGem", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.GreenMiddle            , ST.make(MD.BTL, "greenMiddleGemBlock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreMud         , MT.GreenMiddle            , ST.make(MD.BTL, "greenMiddleGemOre", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.AquaMiddle             , ST.make(MD.BTL, "groundStuff", 1, 45));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.AquaMiddle             , ST.make(MD.BTL, "aquaMiddleGem", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.AquaMiddle             , ST.make(MD.BTL, "aquaMiddleGemBlock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreMud         , MT.AquaMiddle             , ST.make(MD.BTL, "aquaMiddleGemOre", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Valonite               , ST.make(MD.BTL, "unknownGeneric", 1, 22));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Valonite               , ST.make(MD.BTL, "valoniteBlock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.orePitstone    , MT.Valonite               , ST.make(MD.BTL, "valoniteOre", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.S                      , ST.make(MD.BTL, "unknownGeneric", 1, 21));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.S                      , ST.make(MD.BTL, "sulphurBlock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreBetweenstone, MT.S                      , ST.make(MD.BTL, "sulfurOre", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Syrmorite              , ST.make(MD.BTL, "unknownGeneric", 1, 14));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Syrmorite              , ST.make(MD.BTL, "syrmoriteBlock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreBetweenstone, MT.Syrmorite              , ST.make(MD.BTL, "syrmoriteOre", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Octine                 , ST.make(MD.BTL, "unknownGeneric", 1, 15));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Octine                 , ST.make(MD.BTL, "octineBlock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreBetweenstone, MT.Octine                 , ST.make(MD.BTL, "octineOre", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Blaze                  , ST.make(MD.GaNe, "blazeIngot", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.Blaze                  , ST.make(MD.GaNe, "blazeIngot", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Endstone               , ST.make(MD.GaEn, "endstoneRod", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreEndstone    , MT.Endium                 , ST.make(MD.GaEn, "rawEndium", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Endium                 , ST.make(MD.GaEn, "endiumIngot", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.Endium                 , ST.make(MD.GaEn, "endiumIngot", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Endium                 , ST.make(MD.GaEn, "endiumBlock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.InfusedAir             , ST.make(MD.TC, "ItemShard", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.InfusedFire            , ST.make(MD.TC, "ItemShard", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.InfusedWater           , ST.make(MD.TC, "ItemShard", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.InfusedEarth           , ST.make(MD.TC, "ItemShard", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.InfusedOrder           , ST.make(MD.TC, "ItemShard", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.InfusedEntropy         , ST.make(MD.TC, "ItemShard", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.Hg                     , ST.make(MD.TC, "ItemNugget", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.Thaumium               , ST.make(MD.TC, "ItemNugget", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.VoidMetal              , ST.make(MD.TC, "ItemNugget", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Thaumium               , ST.make(MD.TC, "ItemResource", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.VoidMetal              , ST.make(MD.TC, "ItemResource", 1,16));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Hg                     , ST.make(MD.TC, "ItemResource", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Amber                  , ST.make(MD.TC, "ItemResource", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Thaumium               , ST.make(MD.TC, "blockCosmeticSolid", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.DarkMatter             , ST.make(MD.PE, "item.pe_matter", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.RedMatter              , ST.make(MD.PE, "item.pe_matter", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.WaxMagic               , ST.make(MD.FRMB, "wax", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.WaxSoulful             , ST.make(MD.FRMB, "wax", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.WaxAmnesic             , ST.make(MD.FRMB, "wax", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Vinteum                , ST.make(MD.ARS, "itemOre", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.ArcaneCompound         , ST.make(MD.ARS, "itemOre", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.ArcaneAsh              , ST.make(MD.ARS, "itemOre", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.VinteumPurified        , ST.make(MD.ARS, "itemOre", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.UNUSED.Chimerite       , ST.make(MD.ARS, "itemOre", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.BlueTopaz              , ST.make(MD.ARS, "itemOre", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.UNUSED.Sunstone        , ST.make(MD.ARS, "itemOre", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.UNUSED.Moonstone       , ST.make(MD.ARS, "itemOre", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.SmokeyQuartz           , ST.make(MD.BOTA, "quartz", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.ManaQuartz             , ST.make(MD.BOTA, "quartz", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.BlazeQuartz            , ST.make(MD.BOTA, "quartz", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.LavenderQuartz         , ST.make(MD.BOTA, "quartz", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.RedQuartz              , ST.make(MD.BOTA, "quartz", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.ElvenQuartz            , ST.make(MD.BOTA, "quartz", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.SunnyQuartz            , ST.make(MD.BOTA, "quartz", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Manasteel              , ST.make(MD.BOTA, "manaResource", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.ManaDiamond            , ST.make(MD.BOTA, "manaResource", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Livingwood             , ST.make(MD.BOTA, "manaResource", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Terrasteel             , ST.make(MD.BOTA, "manaResource", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.ElvenElementium        , ST.make(MD.BOTA, "manaResource", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.ElvenDragonstone       , ST.make(MD.BOTA, "manaResource", 1, 9));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Dreamwood              , ST.make(MD.BOTA, "manaResource", 1,13));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.GaiaSpirit             , ST.make(MD.BOTA, "manaResource", 1,14));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.Manasteel              , ST.make(MD.BOTA, "manaResource", 1,17));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.Terrasteel             , ST.make(MD.BOTA, "manaResource", 1,18));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.ElvenElementium        , ST.make(MD.BOTA, "manaResource", 1,19));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Manasteel              , ST.make(MD.BOTA, "storage", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Terrasteel             , ST.make(MD.BOTA, "storage", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.ElvenElementium        , ST.make(MD.BOTA, "storage", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.ManaDiamond            , ST.make(MD.BOTA, "storage", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.ElvenDragonstone       , ST.make(MD.BOTA, "storage", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.Livingwood             , ST.make(MD.BOTA, "livingwood", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.Dreamwood              , ST.make(MD.BOTA, "dreamwood", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.Shimmerwood            , ST.make(MD.BOTA, "shimmerwoodPlanks", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreLivingrock  , MT.ElvenDragonstone       , ST.make(MD.ALF, "ElvenOre", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreLivingrock  , MT.ElvenElementium        , ST.make(MD.ALF, "ElvenOre", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.oreLivingrock  , MT.ElvenQuartz            , ST.make(MD.ALF, "ElvenOre", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.oreLivingrock  , MT.Au                     , ST.make(MD.ALF, "ElvenOre", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.oreLivingrock  , MT.Iffesal                , ST.make(MD.ALF, "ElvenOre", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Mauftrium              , ST.make(MD.ALF, "MauftriumBlock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Elvorium               , ST.make(MD.ALF, "ElvoriumBlock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Elvorium               , ST.make(MD.ALF, "ElvenItems", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Mauftrium              , ST.make(MD.ALF, "ElvenItems", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.MuspelheimPower        , ST.make(MD.ALF, "ElvenItems", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.NiflheimPower          , ST.make(MD.ALF, "ElvenItems", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.Elvorium               , ST.make(MD.ALF, "ElvenItems", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.Mauftrium              , ST.make(MD.ALF, "ElvenItems", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Iffesal                , ST.make(MD.ALF, "ElvenItems", 1, 10));
		OreDictManager.INSTANCE.setTarget(OP.dustTiny       , MT.Ag                     , ST.make(MD.WTCH, "ingredient", 1, 157));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Bedrockium             , ST.make(MD.ExU, "block_bedrockium", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Bedrockium             , ST.make(MD.ExU, "bedrockiumIngot", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Chocolate              , ST.make(MD.AA, "itemFood", 1, 9));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.BlackQuartz            , ST.make(MD.AA, "itemDust", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.BlackQuartz            , ST.make(MD.AA, "itemMisc", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Redstonia              , ST.make(MD.AA, "itemCrystal", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Palis                  , ST.make(MD.AA, "itemCrystal", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Diamantine             , ST.make(MD.AA, "itemCrystal", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.VoidCrystal            , ST.make(MD.AA, "itemCrystal", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Emeradic               , ST.make(MD.AA, "itemCrystal", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Enori                  , ST.make(MD.AA, "itemCrystal", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Redstonia              , ST.make(MD.AA, "blockCrystal", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Palis                  , ST.make(MD.AA, "blockCrystal", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Diamantine             , ST.make(MD.AA, "blockCrystal", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.VoidCrystal            , ST.make(MD.AA, "blockCrystal", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Emeradic               , ST.make(MD.AA, "blockCrystal", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Enori                  , ST.make(MD.AA, "blockCrystal", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Charcoal               , ST.make(MD.AA, "blockMisc", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.CoalCoke               , ST.make(MD.RC, "cube", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.CoalCoke               , ST.make(MD.RC, "fuel.coke", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Firestone              , ST.make(MD.RC, "firestone.raw", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.S                      , ST.make(MD.RC, "ore", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreSandstone   , MT.KNO3                   , ST.make(MD.RC, "ore", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.oreBasalt      , MT.Diamond                , ST.make(MD.RC, "ore", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.oreBasalt      , MT.Emerald                , ST.make(MD.RC, "ore", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.oreBasalt      , MT.Lapis                  , ST.make(MD.RC, "ore", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.oreNetherrack  , MT.Firestone              , ST.make(MD.RC, "ore", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.Fe                     , ST.make(MD.RC, "part.plate", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.Steel                  , ST.make(MD.RC, "part.plate", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.TinAlloy               , ST.make(MD.RC, "part.plate", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.Cu                     , ST.make(MD.RC, "part.plate", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.Pb                     , ST.make(MD.RC, "part.plate", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.Al                     , ST.make(MD.MaCu, "crafting", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.Au                     , ST.make(MD.MaCu, "crafting", 1,13));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.Ti                     , ST.make(MD.MaCu, "crafting", 1,17));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.MeatRaw                , ST.make(MD.MFR, "meat.nugget.raw", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.MeatCooked             , ST.make(MD.MFR, "meat.nugget.cooked", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.MeatRaw                , ST.make(MD.MFR, "meat.ingot.raw", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.MeatCooked             , ST.make(MD.MFR, "meat.ingot.cooked", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dustSmall      , MT.FishRaw                , ST.make(MD.MaCu, "materials", 1, 14));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.WoodPolished           , ST.make(MD.MaCu, "crafting", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.WoodPolished           , ST.make(MD.MaCu, "woods", 1, 1));
//      OreDictManager.INSTANCE.setTarget(OP.plate          , MT.WoodSealed             , ST.make(MD.IE, "treatedWood", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.WoodSealed             , ST.make(MD.IE, "material", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.CoalCoke               , ST.make(MD.IE, "material", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.CoalCoke               , ST.make(MD.IE, "metal", 1, 17));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.NetherQuartz           , ST.make(MD.IE, "metal", 1, 18));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Cu                     , ST.make(MD.IE, "ore", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.OREMATS.Bauxite        , ST.make(MD.IE, "ore", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Pb                     , ST.make(MD.IE, "ore", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Ag                     , ST.make(MD.IE, "ore", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Ni                     , ST.make(MD.IE, "ore", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.oreLimestone   , MT.Phosphorus             , ST.make(MD.MIN, "phosphorous_ore", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreDense       , MT.OREMATS.Gypsum         , ST.make(MD.MIN, "gypsum", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreDense       , MT.S                      , ST.make(MD.MIN, "sulfur_ore", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreDense       , MT.Niter                  , ST.make(MD.MIN, "nitrate_ore", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.ChargedCertusQuartz    , ST.make(MD.AE, "item.ItemMultiMaterial", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Draconium              , ST.make(MD.DE, "draconiumDust", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.Draconium              , ST.make(MD.DE, "nugget", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Draconium              , ST.make(MD.DE, "draconiumIngot", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Draconium              , ST.make(MD.DE, "draconium", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.DraconiumAwakened      , ST.make(MD.DE, "nugget", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.DraconiumAwakened      , ST.make(MD.DE, "draconicIngot", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.DraconiumAwakened      , ST.make(MD.DE, "draconicBlock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.CrystalMatrix          , ST.make(MD.AV, "Resource", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.CosmicNeutronium       , ST.make(MD.AV, "Resource", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.CosmicNeutronium       , ST.make(MD.AV, "Resource", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Infinity               , ST.make(MD.AV, "Resource", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.CosmicNeutronium       , ST.make(MD.AV, "Resource_Block", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Infinity               , ST.make(MD.AV, "Resource_Block", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.CrystalMatrix          , ST.make(MD.AV, "Crystal_Matrix", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.bottle         , MT.H2SO4                  , ST.make(MD.FZ, "acid", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.bottle         , MT.AquaRegia              , ST.make(MD.FZ, "acid", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.dustImpure     , MT.Netherrack             , ST.make(MD.FZ, "nether_powder", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.gemChipped     , MT.EnderPearl             , ST.make(MD.RT, "ingredient", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Ectoplasm              , ST.make(MD.RT, "ingredient", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.SpectreIron            , ST.make(MD.RT, "ingredient", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.EnderiumBase           , ST.make(MD.EIO, "itemPowderIngot", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.ElectricalSteel        , ST.make(MD.EIO, "itemAlloy", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.EnergeticAlloy         , ST.make(MD.EIO, "itemAlloy", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.VibrantAlloy           , ST.make(MD.EIO, "itemAlloy", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.RedstoneAlloy          , ST.make(MD.EIO, "itemAlloy", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.ConductiveIron         , ST.make(MD.EIO, "itemAlloy", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.PulsatingIron          , ST.make(MD.EIO, "itemAlloy", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.ObsidianSteel          , ST.make(MD.EIO, "itemAlloy", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Soularium              , ST.make(MD.EIO, "itemAlloy", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.PulsatingIron          , ST.make(MD.EIO, "itemMaterial", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.VibrantAlloy           , ST.make(MD.EIO, "itemMaterial", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.ElectricalSteel        , ST.make(MD.EIO, "blockIngotStorage", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.EnergeticAlloy         , ST.make(MD.EIO, "blockIngotStorage", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.VibrantAlloy           , ST.make(MD.EIO, "blockIngotStorage", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.RedstoneAlloy          , ST.make(MD.EIO, "blockIngotStorage", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.ConductiveIron         , ST.make(MD.EIO, "blockIngotStorage", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.PulsatingIron          , ST.make(MD.EIO, "blockIngotStorage", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.ObsidianSteel          , ST.make(MD.EIO, "blockIngotStorage", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Soularium              , ST.make(MD.EIO, "blockIngotStorage", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.ObsidianSteel          , ST.make(MD.TG, "TechgunsAmmo", 1, 40));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.ObsidianSteel          , ST.make(MD.TG, "TechgunsAmmo", 1, 65));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.C                      , ST.make(MD.TG, "TechgunsAmmo", 1, 62));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.Plastic                , ST.make(MD.TG, "TechgunsAmmo", 1, 72));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Plastic                , ST.make(MD.TG, "TechgunsAmmo", 1, 71));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.U_235                  , ST.make(MD.TG, "TechgunsAmmo", 1,102));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Stone                  , ST.make(MD.FMB, "stoneRod", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Bark                   , ST.make(MD.BINNIE_TREE, "misc", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.dustSmall      , MT.Ash                    , ST.make(MD.BINNIE_BOTANY, "misc", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dustSmall      , MT.Wood                   , ST.make(MD.BINNIE_BOTANY, "misc", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.dustSmall      , MT.S                      , ST.make(MD.BINNIE_BOTANY, "misc", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.gemOre         , MT.Goshenite              , ST.make(MD.VOLTZ, "gems", 1,   10));
		OreDictManager.INSTANCE.setTarget(OP.gemRaw         , MT.Goshenite              , ST.make(MD.VOLTZ, "gems", 1, 1010));
		OreDictManager.INSTANCE.setTarget(OP.gemUncut       , MT.Goshenite              , ST.make(MD.VOLTZ, "gems", 1, 2010));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Goshenite              , ST.make(MD.VOLTZ, "gems", 1, 3010));
		OreDictManager.INSTANCE.setTarget(OP.gemPolished    , MT.Goshenite              , ST.make(MD.VOLTZ, "gems", 1, 4010));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.TungstenCarbide        , ST.make(MD.MgC, "item.ingotCarbide", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Yellorite              , ST.make(MD.BR, "YelloriteOre", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Yellorium              , ST.make(MD.BR, "BRMetalBlock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Cyanite                , ST.make(MD.BR, "BRMetalBlock", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Graphite               , ST.make(MD.BR, "BRMetalBlock", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Blutonium              , ST.make(MD.BR, "BRMetalBlock", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Ludicrite              , ST.make(MD.BR, "BRMetalBlock", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Yellorium              , ST.make(MD.BR, "BRIngot", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Cyanite                , ST.make(MD.BR, "BRIngot", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Graphite               , ST.make(MD.BR, "BRIngot", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Blutonium              , ST.make(MD.BR, "BRIngot", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Yellorium              , ST.make(MD.BR, "BRIngot", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Cyanite                , ST.make(MD.BR, "BRIngot", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Graphite               , ST.make(MD.BR, "BRIngot", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Blutonium              , ST.make(MD.BR, "BRIngot", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Ludicrite              , ST.make(MD.BR, "BRIngot", 1, 8));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Ludicrite              , ST.make(MD.BR, "BRIngot", 1, 9));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Sn                     , ST.make(MD.ElC, "electricraft_block_ore", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Ag                     , ST.make(MD.ElC, "electricraft_block_ore", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Ni                     , ST.make(MD.ElC, "electricraft_block_ore", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Al                     , ST.make(MD.ElC, "electricraft_block_ore", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Pt                     , ST.make(MD.ElC, "electricraft_block_ore", 1, 5));
//      OreDictManager.INSTANCE.setTarget(OP.dust           , MT.HydrogenFluoride       , ST.make(MD.ReC, "reactorcraft_item_raw", 1, 0));
//      OreDictManager.INSTANCE.setTarget(OP.dust           , MT.UraniumEnriched        , ST.make(MD.ReC, "reactorcraft_item_raw", 1, 1));
//      OreDictManager.INSTANCE.setTarget(OP.dust           , MT.UraniumDepleted        , ST.make(MD.ReC, "reactorcraft_item_raw", 1, 2));
//      OreDictManager.INSTANCE.setTarget(OP.dust           , MT.AmmoniumChloride       , ST.make(MD.ReC, "reactorcraft_item_raw", 1, 3)); // registered as dustAmmonium
//      OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Quicklime              , ST.make(MD.ReC, "reactorcraft_item_raw", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.CaCO3                  , ST.make(MD.ReC, "reactorcraft_item_raw", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.OREMATS.Magnetite      , ST.make(MD.ReC, "reactorcraft_item_raw", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Th                     , ST.make(MD.ReC, "reactorcraft_item_raw", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Emerald                , ST.make(MD.ReC, "reactorcraft_item_raw", 1, 8));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Cd_In_Ag_Alloy         , ST.make(MD.ReC, "reactorcraft_item_crafting", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.SteelMagnetic          , ST.make(MD.ReC, "reactorcraft_item_crafting", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.SteelMagnetic          , ST.make(MD.ReC, "reactorcraft_item_crafting", 1,10));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.U_238                  , ST.make(MD.ReC, "reactorcraft_item_crafting", 1,14));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.TungstenCarbide        , ST.make(MD.ReC, "reactorcraft_item_crafting", 1,17));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.CaCO3                  , ST.make(MD.ReC, "reactorcraft_block_mats", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.OREMATS.Pitchblende    , ST.make(MD.ReC, "reactorcraft_block_ore", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Cd                     , ST.make(MD.ReC, "reactorcraft_block_ore", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.In                     , ST.make(MD.ReC, "reactorcraft_block_ore", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Ag                     , ST.make(MD.ReC, "reactorcraft_block_ore", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.oreEndstone    , MT.OREMATS.Pitchblende    , ST.make(MD.ReC, "reactorcraft_block_ore", 1, 5));
//      OreDictManager.INSTANCE.setTarget(OP.oreNetherrack  , MT.AmmoniumChloride       , ST.make(MD.ReC, "reactorcraft_block_ore", 1, 6)); // registered as oreAmmonium
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.CaCO3                  , ST.make(MD.ReC, "reactorcraft_block_ore", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.OREMATS.Magnetite      , ST.make(MD.ReC, "reactorcraft_block_ore", 1, 8));
		OreDictManager.INSTANCE.setTarget(OP.oreNetherrack  , MT.Th                     , ST.make(MD.ReC, "reactorcraft_block_ore", 1, 9));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.FluoriteBlue           , ST.make(MD.ReC, "reactorcraft_block_fluoriteore", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.FluoritePink           , ST.make(MD.ReC, "reactorcraft_block_fluoriteore", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.FluoriteOrange         , ST.make(MD.ReC, "reactorcraft_block_fluoriteore", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.FluoriteMagenta        , ST.make(MD.ReC, "reactorcraft_block_fluoriteore", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.FluoriteGreen          , ST.make(MD.ReC, "reactorcraft_block_fluoriteore", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.FluoriteRed            , ST.make(MD.ReC, "reactorcraft_block_fluoriteore", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.FluoriteWhite          , ST.make(MD.ReC, "reactorcraft_block_fluoriteore", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.FluoriteYellow         , ST.make(MD.ReC, "reactorcraft_block_fluoriteore", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.FluoriteBlue           , ST.make(MD.ReC, "reactorcraft_block_fluorite", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.FluoritePink           , ST.make(MD.ReC, "reactorcraft_block_fluorite", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.FluoriteOrange         , ST.make(MD.ReC, "reactorcraft_block_fluorite", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.FluoriteMagenta        , ST.make(MD.ReC, "reactorcraft_block_fluorite", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.FluoriteGreen          , ST.make(MD.ReC, "reactorcraft_block_fluorite", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.FluoriteRed            , ST.make(MD.ReC, "reactorcraft_block_fluorite", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.FluoriteWhite          , ST.make(MD.ReC, "reactorcraft_block_fluorite", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.FluoriteYellow         , ST.make(MD.ReC, "reactorcraft_block_fluorite", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.FluoriteBlue           , ST.make(MD.ReC, "reactorcraft_item_fluorite", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.FluoritePink           , ST.make(MD.ReC, "reactorcraft_item_fluorite", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.FluoriteOrange         , ST.make(MD.ReC, "reactorcraft_item_fluorite", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.FluoriteMagenta        , ST.make(MD.ReC, "reactorcraft_item_fluorite", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.FluoriteGreen          , ST.make(MD.ReC, "reactorcraft_item_fluorite", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.FluoriteRed            , ST.make(MD.ReC, "reactorcraft_item_fluorite", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.FluoriteWhite          , ST.make(MD.ReC, "reactorcraft_item_fluorite", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.FluoriteYellow         , ST.make(MD.ReC, "reactorcraft_item_fluorite", 1, 7));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.CaF2                   , ST.make(MD.RoC, "rotarycraft_item_modingots", 1, 52));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Netherrack             , ST.make(MD.RoC, "rotarycraft_item_powders", 1, 0));
//      OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Tar                    , ST.make(MD.RoC, "rotarycraft_item_powders", 1, 1));
//      OreDictManager.INSTANCE.setTarget(OP.dust           , MT.SludgeOrganic          , ST.make(MD.RoC, "rotarycraft_item_powders", 1, 2)); smelts into ethanol
		OreDictManager.INSTANCE.setTarget(OP.dustSmall      , MT.Wood                   , ST.make(MD.RoC, "rotarycraft_item_powders", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Bedrock                , ST.make(MD.RoC, "rotarycraft_item_powders", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.NaCl                   , ST.make(MD.RoC, "rotarycraft_item_powders", 1, 5));
//      OreDictManager.INSTANCE.setTarget(OP.dust           , MT.AmmoniumNitrate        , ST.make(MD.RoC, "rotarycraft_item_powders", 1, 6)); Salt + Coal + Gunpowder + Redstone = 4 (180, 150, 200)
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.AgI                    , ST.make(MD.RoC, "rotarycraft_item_powders", 1, 7));
//      OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Al                     , ST.make(MD.RoC, "rotarycraft_item_powders", 1, 8)); No Target needed
		OreDictManager.INSTANCE.setTarget(OP.dustSmall      , MT.Wheat                  , ST.make(MD.RoC, "rotarycraft_item_powders", 1, 9));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Coal                   , ST.make(MD.RoC, "rotarycraft_item_powders", 1,10));
//      OreDictManager.INSTANCE.setTarget(OP.dust           , MT.DryIce                 , ST.make(MD.RoC, "rotarycraft_item_powders", 1,11));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.InductiveAlloy         , ST.make(MD.RoC, "rotarycraft_item_powders", 1,12));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Si                     , ST.make(MD.RoC, "rotarycraft_item_powders", 1,14));
//      OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Ethanol                , ST.make(MD.RoC, "rotarycraft_item_ethanol", 1, 0)); burns for 400 furnace time
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Anthracite             , ST.make(MD.RoC, "rotarycraft_item_compacts", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Prismane               , ST.make(MD.RoC, "rotarycraft_item_compacts", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Lonsdaleite            , ST.make(MD.RoC, "rotarycraft_item_compacts", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Bedrock_HSLA_Alloy     , ST.make(MD.RoC, "rotarycraft_item_compacts", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.TungstenSintered       , ST.make(MD.RoC, "rotarycraft_item_compacts", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.InductiveAlloy         , ST.make(MD.RoC, "rotarycraft_item_compacts", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.CoalCoke               , ST.make(MD.RoC, "rotarycraft_item_compacts", 1, 8));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.SpringSteel            , ST.make(MD.RoC, "rotarycraft_item_compacts", 1, 9));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Si                     , ST.make(MD.RoC, "rotarycraft_item_compacts", 1,10));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.AluminiumAlloy         , ST.make(MD.RoC, "rotarycraft_item_compacts", 1,11));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.HSLA                   , ST.make(MD.RoC, "rotarycraft_item_shaftcraft", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.HSLA                   , ST.make(MD.RoC, "rotarycraft_item_shaftcraft", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.stickLong      , MT.HSLA                   , ST.make(MD.RoC, "rotarycraft_item_shaftcraft", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.HSLA                   , ST.make(MD.RoC, "rotarycraft_block_deco", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Anthracite             , ST.make(MD.RoC, "rotarycraft_block_deco", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Lonsdaleite            , ST.make(MD.RoC, "rotarycraft_block_deco", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Bedrock_HSLA_Alloy     , ST.make(MD.RoC, "rotarycraft_block_deco", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.CoalCoke               , ST.make(MD.RoC, "rotarycraft_block_deco", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.stickLong      , MT.Stone                  , ST.make(MD.RoC, "rotarycraft_item_borecraft", 1, 13));
		OreDictManager.INSTANCE.setTarget(OP.stickLong      , MT.Diamond                , ST.make(MD.RoC, "rotarycraft_item_borecraft", 1, 14));
//      OreDictManager.INSTANCE.setTarget(OP.stickLong      , MT.Livingwood             , ST.make(MD.RoC, "rotarycraft_item_modinterface", 1, 17));
//      OreDictManager.INSTANCE.setTarget(OP.stickLong      , MT.Livingrock             , ST.make(MD.RoC, "rotarycraft_item_modinterface", 1, 18));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Nutmeg                 , ST.make(MD.HaC, "groundnutmegItem", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Cinnamon               , ST.make(MD.HaC, "groundcinnamonItem", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Cocoa                  , ST.make(MD.HaC, "cocoapowderItem", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Curry                  , ST.make(MD.HaC, "currypowderItem", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.WaxPlant               , ST.make(MD.HaC, "waxItem", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.WaxBee                 , ST.make(MD.HaC, "beeswaxItem", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Corn                   , ST.make(MD.PMP, "foodCornFlour", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Rice                   , ST.make(MD.PMP, "foodCookedRice", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Wood                   , ST.make(MD.FR, "woodPulp", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.WaxBee                 , ST.make(MD.FR, "beeswax", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.WaxRefractory          , ST.make(MD.FR, "refractoryWax", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Peat                   , ST.make(MD.FR, "peat", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingotDouble    , MT.PeatBituminous         , ST.make(MD.FR, "bituminousPeat", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dustImpure     , MT.Fe                     , ST.make(MD.Mek, "DirtyDust", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dustImpure     , MT.Au                     , ST.make(MD.Mek, "DirtyDust", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.dustImpure     , MT.FakeOsmium             , ST.make(MD.Mek, "DirtyDust", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.dustImpure     , MT.Cu                     , ST.make(MD.Mek, "DirtyDust", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.dustImpure     , MT.Sn                     , ST.make(MD.Mek, "DirtyDust", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.dustImpure     , MT.Ag                     , ST.make(MD.Mek, "DirtyDust", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.dustImpure     , MT.Pb                     , ST.make(MD.Mek, "DirtyDust", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.RefinedObsidian        , ST.make(MD.Mek, "OtherDust", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.RefinedObsidian        , ST.make(MD.Mek, "Ingot", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.RefinedObsidian        , ST.make(MD.Mek, "BasicBlock", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.RefinedGlowstone       , ST.make(MD.Mek, "Ingot", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.RefinedGlowstone       , ST.make(MD.Mek, "BasicBlock", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.FakeOsmium             , ST.make(MD.Mek, "Dust", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.FakeOsmium             , ST.make(MD.Mek, "Ingot", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.FakeOsmium             , ST.make(MD.Mek, "BasicBlock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.FakeOsmium             , ST.make(MD.Mek, "OreBlock", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Cu                     , ST.make(MD.Mek, "OreBlock", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Sn                     , ST.make(MD.Mek, "OreBlock", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.WaxBee                 , ST.make(MD.GrC_Bees, "grcbees.BeesWax", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Eudialyte              , ST.make(MD.TROPIC, "tile.oreEudialyte", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Zircon                 , ST.make(MD.TROPIC, "tile.oreZircon", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Azurite                , ST.make(MD.TROPIC, "tile.oreAzurite", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Eudialyte              , ST.make(MD.TROPIC, "tile.blockOre", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Zircon                 , ST.make(MD.TROPIC, "tile.blockOre", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Azurite                , ST.make(MD.TROPIC, "tile.blockOre", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Zr                     , ST.make(MD.TROPIC, "tile.blockOre", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Eudialyte              , ST.make(MD.TROPIC, "ore", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Zircon                 , ST.make(MD.TROPIC, "ore", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Azurite                , ST.make(MD.TROPIC, "ore", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Zr                     , ST.make(MD.TROPIC, "ore", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Marshmallow            , ST.make(MD.CANDY, "I21", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Sugar                  , ST.make(MD.CANDY, "I69", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Honey                  , ST.make(MD.CANDY, "I23", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Honey                  , ST.make(MD.CANDY, "B59", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Honey                  , ST.make(MD.CANDY, "B57", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.PEZ                    , ST.make(MD.CANDY, "I49", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.PEZ                    , ST.make(MD.CANDY, "I48", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.PEZ                    , ST.make(MD.CANDY, "B62", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.PEZ                    , ST.make(MD.CANDY, "B61", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Licorice               , ST.make(MD.CANDY, "I0" , 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Licorice               , ST.make(MD.CANDY, "B12", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Licorice               , ST.make(MD.CANDY, "B14", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Nougat                 , ST.make(MD.CANDY, "I84", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockDust      , MT.Nougat                 , ST.make(MD.CANDY, "B94", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Nougat                 , ST.make(MD.CANDY, "B91", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Cu                     , ST.make(MD.TE_FOUNDATION, "Ore", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Sn                     , ST.make(MD.TE_FOUNDATION, "Ore", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Ag                     , ST.make(MD.TE_FOUNDATION, "Ore", 1, 2));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Pb                     , ST.make(MD.TE_FOUNDATION, "Ore", 1, 3));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Ni                     , ST.make(MD.TE_FOUNDATION, "Ore", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Pt                     , ST.make(MD.TE_FOUNDATION, "Ore", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Mithril                , ST.make(MD.TE_FOUNDATION, "Ore", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Pyrotheum              , ST.make(MD.TE_FOUNDATION, "material", 1,  512));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Cryotheum              , ST.make(MD.TE_FOUNDATION, "material", 1,  513));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Aerotheum              , ST.make(MD.TE_FOUNDATION, "material", 1,  514));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Petrotheum             , ST.make(MD.TE_FOUNDATION, "material", 1,  515));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Blizz                  , ST.make(MD.TE_FOUNDATION, "material", 1, 1025));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Blitz                  , ST.make(MD.TE_FOUNDATION, "material", 1, 1027));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Basalz                 , ST.make(MD.TE_FOUNDATION, "material", 1, 1029));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Lignite                , ST.make(MD.UB, "ligniteCoal", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreEndstone    , MT.EnderAmethyst          , ST.make(MD.BoP, "gemOre", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.EnderAmethyst          , ST.make(MD.BoP, "gemOre", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.EnderAmethyst          , ST.make(MD.BoP, "gems"  , 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreHolystone   , MT.Zanite                 , ST.make(MD.AETHER, "zaniteOre"     , 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreHolystone   , MT.Ambrosium              , ST.make(MD.AETHER, "ambrosiumOre"  , 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreHolystone   , MT.Gravitite              , ST.make(MD.AETHER, "gravititeOre"  , 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreHolystone   , MT.Continuum              , ST.make(MD.AETHER, "continuumOre"  , 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Zanite                 , ST.make(MD.AETHER, "zaniteGemstone", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Ambrosium              , ST.make(MD.AETHER, "ambrosiumShard", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Continuum              , ST.make(MD.AETHER, "continuumOrb"  , 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Zanite                 , ST.make(MD.AETHER, "zaniteBlock"   , 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Continuum              , ST.make(MD.AETHER, "continuumBomb" , 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Skyroot                , ST.make(MD.AETHER, "skyrootStick"  , 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Coffee                 , ST.mkic("coffeePowder", 1));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.HydratedCoal           , ST.mkic("hydratedCoalDust", 1));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.DiamondIndustrial      , ST.mkic("industrialDiamond", 1));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Cu                     , ST.make(MD.IC2, "blockOreCopper", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Pb                     , ST.make(MD.IC2, "blockOreLead"  , 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Sn                     , ST.make(MD.IC2, "blockOreTin"   , 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.OREMATS.Uraninite      , ST.make(MD.IC2, "blockOreUran"  , 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Cu                     , ST.make(MD.IC2, "copperOre"     , 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Sn                     , ST.make(MD.IC2, "tinOre"        , 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.OREMATS.Uraninite      , ST.make(MD.IC2, "uraniumOre"    , 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.cell           , MT.Creosote               , ST.make(MD.RC, "fluid.creosote.cell", 1));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Bamboo                 , ST.make(MD.PMP, "bambooAsperPole", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Bamboo                 , ST.make(MD.PMP, "bambooFargesiaRobustaPole", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Bamboo                 , ST.make(MD.PMP, "bambooGiantTimberPole", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Bamboo                 , ST.make(MD.PMP, "bambooGoldenPole", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Bamboo                 , ST.make(MD.PMP, "bambooMosoPole", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Bamboo                 , ST.make(MD.PMP, "bambooShortTassledPole", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Bamboo                 , ST.make(MD.PMP, "bambooTimorBlackPole", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Bamboo                 , ST.make(MD.PMP, "bambooTropicalBluePole", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Bamboo                 , ST.make(MD.PMP, "bambooWetForestPole", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Bamboo                 , ST.make(MD.GrC_Bamboo, "grc.bamboo", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Bamboo                 , ST.make(MD.BoP, "bamboo", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Bamboo                 , ST.make(MD.TROPIC, "bambooStick", 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Cu                     , ST.make(MD.ELN, "Eln.Ore", 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Pb                     , ST.make(MD.ELN, "Eln.Ore", 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.W                      , ST.make(MD.ELN, "Eln.Ore", 1, 5));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.OREMATS.Cinnabar       , ST.make(MD.ELN, "Eln.Ore", 1, 6));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.W                      , ST.make(MD.ELN, "Eln.sharedItem", 1,  517));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Li2Fe2O4               , ST.make(MD.ELN, "Eln.sharedItem", 1,  518));
		OreDictManager.INSTANCE.setTarget(OP.chunkGt        , MT.Hg                     , ST.make(MD.ELN, "Eln.sharedItem", 1,  520));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Lapis                  , ST.make(MD.ELN, "Eln.sharedItem", 1,  579));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Diamond                , ST.make(MD.ELN, "Eln.sharedItem", 1,  580));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Rubber                 , ST.make(MD.ELN, "Eln.sharedItem", 1, 4097));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.DiamondIndustrial      , ST.make(MD.ELN, "Eln.sharedItem", 1, 4420));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Si                     , ST.make(MD.ELN, "Eln.sharedItem", 1, 7697));
		OreDictManager.INSTANCE.setTarget(OP.bottle         , MT.Empty                  , ST.make(Items.glass_bottle, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.bottle         , MT.Water                  , ST.make(Items.potionitem, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Coal                   , ST.make(Blocks.coal_ore, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Fe                     , ST.make(Blocks.iron_ore, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Lapis                  , ST.make(Blocks.lapis_ore, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Redstone               , ST.make(Blocks.redstone_ore, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Redstone               , ST.make(Blocks.lit_redstone_ore, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Au                     , ST.make(Blocks.gold_ore, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Diamond                , ST.make(Blocks.diamond_ore, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreVanillastone, MT.Emerald                , ST.make(Blocks.emerald_ore, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.oreNetherrack  , MT.NetherQuartz           , ST.make(Blocks.quartz_ore, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Lapis                  , ST.make(Items.dye, 1, 4));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.EnderEye               , ST.make(Items.ender_eye, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.EnderPearl             , ST.make(Items.ender_pearl, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Diamond                , ST.make(Items.diamond, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Emerald                , ST.make(Items.emerald, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Coal                   , ST.make(Items.coal, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.Charcoal               , ST.make(Items.coal, 1, 1));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.NetherQuartz           , ST.make(Items.quartz, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.gem            , MT.NetherStar             , ST.make(Items.nether_star, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.nugget         , MT.Au                     , ST.make(Items.gold_nugget, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Au                     , ST.make(Items.gold_ingot, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.ingot          , MT.Fe                     , ST.make(Items.iron_ingot, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.plate          , MT.Paper                  , ST.make(Items.paper, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Sugar                  , ST.make(Items.sugar, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Bone                   , ST.make(Items.dye, 1, 15));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Redstone               , ST.make(Items.redstone, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Gunpowder              , ST.make(Items.gunpowder, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Glowstone              , ST.make(Items.glowstone_dust, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.Blaze                  , ST.make(Items.blaze_powder, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Blaze                  , ST.make(Items.blaze_rod, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.stick          , MT.Wood                   , ST.make(Items.stick, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Fe                     , ST.make(Blocks.iron_block, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockIngot     , MT.Au                     , ST.make(Blocks.gold_block, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Diamond                , ST.make(Blocks.diamond_block, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Emerald                , ST.make(Blocks.emerald_block, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Lapis                  , ST.make(Blocks.lapis_block, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockGem       , MT.Coal                   , ST.make(Blocks.coal_block, 1, 0));
		OreDictManager.INSTANCE.setTarget(OP.blockDust      , MT.Redstone               , ST.make(Blocks.redstone_block, 1, 0));
		if (MD.IC2C.mLoaded) {
		OreDictManager.INSTANCE.setTarget(OP.plateDense     , MT.Cu                     , ST.make(MD.IC2, "item.itemPartDCP", 1, 0));
		} else {
		OreDictManager.INSTANCE.setTarget(OP.dust           , MT.EnergiumRed            , ST.mkic("energiumDust", 1));
		OreDictManager.INSTANCE.setTarget(OP.casingSmall    , MT.Fe                     , ST.mkic("casingiron", 1));
		OreDictManager.INSTANCE.setTarget(OP.casingSmall    , MT.Au                     , ST.mkic("casinggold", 1));
		OreDictManager.INSTANCE.setTarget(OP.casingSmall    , MT.Cu                     , ST.mkic("casingcopper", 1));
		OreDictManager.INSTANCE.setTarget(OP.casingSmall    , MT.Sn                     , ST.mkic("casingtin", 1));
		OreDictManager.INSTANCE.setTarget(OP.casingSmall    , MT.Pb                     , ST.mkic("casinglead", 1));
		OreDictManager.INSTANCE.setTarget(OP.casingSmall    , MT.Bronze                 , ST.mkic("casingbronze", 1));
		OreDictManager.INSTANCE.setTarget(OP.casingSmall    , MT.Steel                  , ST.mkic("casingadviron", 1));
		}
	}
}
